@@ -7,7 +7,9 @@
 package Debian::Debhelper::Buildsystem::perl_build;
 
 use strict;
+use Debian::Debhelper::Dh_Lib qw(compat);
 use base 'Debian::Debhelper::Buildsystem';
+use Config;
 
 sub DESCRIPTION {
 	"Perl Module::Build (Build.PL)"
@@ -38,8 +40,15 @@ sub new {
 
 sub configure {
 	my $this=shift;
+	my @flags;
 	$ENV{PERL_MM_USE_DEFAULT}=1;
-	$this->do_perl("Build.PL", "installdirs=vendor", @_);
+	if ($ENV{CFLAGS} && ! compat(8)) {
+		push @flags, "config=optimize=$ENV{CFLAGS} $ENV{CPPFLAGS}";
+	}
+	if ($ENV{LDFLAGS} && ! compat(8)) {
+		push @flags, "config=ld=$Config{ld} $ENV{CFLAGS} $ENV{LDFLAGS}";
+	}
+	$this->do_perl("Build.PL", "installdirs=vendor", @flags, @_);
 }
 
 sub build {
